Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiKeyMiddleware ¶
ApiKeyMiddleware authenticates requests using a predefined API key.
func RoleInstanceMiddleware ¶
RoleInstanceMiddleware checks if the user is an admin and if they belong to the instance specified in the URL.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.